==> zio-aws-iottwinmaker_2.13-5.17.116.2-sources.jar: zio/aws/iottwinmaker/model/EntitySummary.scala <==
package zio.aws.iottwinmaker.model
import zio.aws.iottwinmaker.model.primitives.{
  TwinMakerArn,
  Timestamp,
  ParentEntityId,
  Description,
  EntityId,
  EntityName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class EntitySummary(
    arn: TwinMakerArn,
    creationDateTime: Timestamp,
    description: Option[Description] = None,
    entityId: EntityId,
    entityName: EntityName,
    hasChildEntities: Option[Boolean] = None,
    parentEntityId: Option[ParentEntityId] = None,
    status: zio.aws.iottwinmaker.model.Status,
    updateDateTime: Timestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.EntitySummary = {
    import EntitySummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.EntitySummary
      .builder()
      .arn(TwinMakerArn.unwrap(arn): java.lang.String)
      .creationDateTime(Timestamp.unwrap(creationDateTime): Instant)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .entityId(EntityId.unwrap(entityId): java.lang.String)
      .entityName(EntityName.unwrap(entityName): java.lang.String)
      .optionallyWith(hasChildEntities.map(value => value: java.lang.Boolean))(
        _.hasChildEntities
      )
      .optionallyWith(
        parentEntityId.map(value =>
          ParentEntityId.unwrap(value): java.lang.String
        )
      )(_.parentEntityId)
      .status(status.buildAwsValue())
      .updateDateTime(Timestamp.unwrap(updateDateTime): Instant)
      .build()
  }
  def asReadOnly: zio.aws.iottwinmaker.model.EntitySummary.ReadOnly =
    zio.aws.iottwinmaker.model.EntitySummary.wrap(buildAwsValue())
}
object EntitySummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.EntitySummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.EntitySummary =
      zio.aws.iottwinmaker.model.EntitySummary(
        arn,
        creationDateTime,
        description.map(value => value),
        entityId,
        entityName,
        hasChildEntities.map(value => value),
        parentEntityId.map(value => value),
        status.asEditable,
        updateDateTime
      )
    def arn: TwinMakerArn
    def creationDateTime: Timestamp
    def description: Option[Description]
    def entityId: EntityId
    def entityName: EntityName
    def hasChildEntities: Option[Boolean]
    def parentEntityId: Option[ParentEntityId]
    def status: zio.aws.iottwinmaker.model.Status.ReadOnly
    def updateDateTime: Timestamp
    def getArn: ZIO[Any, Nothing, TwinMakerArn] = ZIO.succeed(arn)
    def getCreationDateTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationDateTime)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getEntityId: ZIO[Any, Nothing, EntityId] = ZIO.succeed(entityId)
    def getEntityName: ZIO[Any, Nothing, EntityName] = ZIO.succeed(entityName)
    def getHasChildEntities: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("hasChildEntities", hasChildEntities)
    def getParentEntityId: ZIO[Any, AwsError, ParentEntityId] =
      AwsError.unwrapOptionField("parentEntityId", parentEntityId)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.iottwinmaker.model.Status.ReadOnly] =
      ZIO.succeed(status)
    def getUpdateDateTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(updateDateTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.EntitySummary
  ) extends zio.aws.iottwinmaker.model.EntitySummary.ReadOnly {
    override val arn: TwinMakerArn =
      zio.aws.iottwinmaker.model.primitives.TwinMakerArn(impl.arn())
    override val creationDateTime: Timestamp =
      zio.aws.iottwinmaker.model.primitives.Timestamp(impl.creationDateTime())
    override val description: Option[Description] = scala
      .Option(impl.description())
      .map(value => zio.aws.iottwinmaker.model.primitives.Description(value))
    override val entityId: EntityId =
      zio.aws.iottwinmaker.model.primitives.EntityId(impl.entityId())
    override val entityName: EntityName =
      zio.aws.iottwinmaker.model.primitives.EntityName(impl.entityName())
    override val hasChildEntities: Option[Boolean] =
      scala.Option(impl.hasChildEntities()).map(value => value: Boolean)
    override val parentEntityId: Option[ParentEntityId] = scala
      .Option(impl.parentEntityId())
      .map(value => zio.aws.iottwinmaker.model.primitives.ParentEntityId(value))
    override val status: zio.aws.iottwinmaker.model.Status.ReadOnly =
      zio.aws.iottwinmaker.model.Status.wrap(impl.status())
    override val updateDateTime: Timestamp =
      zio.aws.iottwinmaker.model.primitives.Timestamp(impl.updateDateTime())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.EntitySummary
  ): zio.aws.iottwinmaker.model.EntitySummary.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iottwinmaker_2.13-5.17.208.2-sources.jar: zio/aws/iottwinmaker/model/EntitySummary.scala <==
package zio.aws.iottwinmaker.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.iottwinmaker.model.primitives.{
  TwinMakerArn,
  Timestamp,
  ParentEntityId,
  Description,
  EntityId,
  EntityName
}
import scala.jdk.CollectionConverters._
final case class EntitySummary(
    arn: TwinMakerArn,
    creationDateTime: Timestamp,
    description: Optional[Description] = Optional.Absent,
    entityId: EntityId,
    entityName: EntityName,
    hasChildEntities: Optional[Boolean] = Optional.Absent,
    parentEntityId: Optional[ParentEntityId] = Optional.Absent,
    status: zio.aws.iottwinmaker.model.Status,
    updateDateTime: Timestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.EntitySummary = {
    import EntitySummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.EntitySummary
      .builder()
      .arn(TwinMakerArn.unwrap(arn): java.lang.String)
      .creationDateTime(Timestamp.unwrap(creationDateTime): Instant)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .entityId(EntityId.unwrap(entityId): java.lang.String)
      .entityName(EntityName.unwrap(entityName): java.lang.String)
      .optionallyWith(hasChildEntities.map(value => value: java.lang.Boolean))(
        _.hasChildEntities
      )
      .optionallyWith(
        parentEntityId.map(value =>
          ParentEntityId.unwrap(value): java.lang.String
        )
      )(_.parentEntityId)
      .status(status.buildAwsValue())
      .updateDateTime(Timestamp.unwrap(updateDateTime): Instant)
      .build()
  }
  def asReadOnly: zio.aws.iottwinmaker.model.EntitySummary.ReadOnly =
    zio.aws.iottwinmaker.model.EntitySummary.wrap(buildAwsValue())
}
object EntitySummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.EntitySummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.EntitySummary =
      zio.aws.iottwinmaker.model.EntitySummary(
        arn,
        creationDateTime,
        description.map(value => value),
        entityId,
        entityName,
        hasChildEntities.map(value => value),
        parentEntityId.map(value => value),
        status.asEditable,
        updateDateTime
      )
    def arn: TwinMakerArn
    def creationDateTime: Timestamp
    def description: Optional[Description]
    def entityId: EntityId
    def entityName: EntityName
    def hasChildEntities: Optional[Boolean]
    def parentEntityId: Optional[ParentEntityId]
    def status: zio.aws.iottwinmaker.model.Status.ReadOnly
    def updateDateTime: Timestamp
    def getArn: ZIO[Any, Nothing, TwinMakerArn] = ZIO.succeed(arn)
    def getCreationDateTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationDateTime)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getEntityId: ZIO[Any, Nothing, EntityId] = ZIO.succeed(entityId)
    def getEntityName: ZIO[Any, Nothing, EntityName] = ZIO.succeed(entityName)
    def getHasChildEntities: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("hasChildEntities", hasChildEntities)
    def getParentEntityId: ZIO[Any, AwsError, ParentEntityId] =
      AwsError.unwrapOptionField("parentEntityId", parentEntityId)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.iottwinmaker.model.Status.ReadOnly] =
      ZIO.succeed(status)
    def getUpdateDateTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(updateDateTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.EntitySummary
  ) extends zio.aws.iottwinmaker.model.EntitySummary.ReadOnly {
    override val arn: TwinMakerArn =
      zio.aws.iottwinmaker.model.primitives.TwinMakerArn(impl.arn())
    override val creationDateTime: Timestamp =
      zio.aws.iottwinmaker.model.primitives.Timestamp(impl.creationDateTime())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iottwinmaker.model.primitives.Description(value))
    override val entityId: EntityId =
      zio.aws.iottwinmaker.model.primitives.EntityId(impl.entityId())
    override val entityName: EntityName =
      zio.aws.iottwinmaker.model.primitives.EntityName(impl.entityName())
    override val hasChildEntities: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.hasChildEntities())
      .map(value => value: Boolean)
    override val parentEntityId: Optional[ParentEntityId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parentEntityId())
        .map(value =>
          zio.aws.iottwinmaker.model.primitives.ParentEntityId(value)
        )
    override val status: zio.aws.iottwinmaker.model.Status.ReadOnly =
      zio.aws.iottwinmaker.model.Status.wrap(impl.status())
    override val updateDateTime: Timestamp =
      zio.aws.iottwinmaker.model.primitives.Timestamp(impl.updateDateTime())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.EntitySummary
  ): zio.aws.iottwinmaker.model.EntitySummary.ReadOnly = new Wrapper(impl)
}
